==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway.md <==
# AmazonVpcVpnGateway


```text
aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway
```

```text
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway')
```



| Illustration | AmazonVpcVpnGateway | AmazonVpcVpnGatewayCard | AmazonVpcVpnGatewayGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway.png) | ![illustration for AmazonVpcVpnGateway](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway.Local.png) | ![illustration for AmazonVpcVpnGatewayCard](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGatewayCard.Local.png) | ![illustration for AmazonVpcVpnGatewayGroup](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGatewayGroup.Local.png) |




## AmazonVpcVpnGateway

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnGateway
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway')

' renders the element
AmazonVpcVpnGateway('AmazonVpcVpnGateway', 'Amazon Vpc Vpn Gateway', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnGateway
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway')

' renders the element
AmazonVpcVpnGateway('AmazonVpcVpnGateway', 'Amazon Vpc Vpn Gateway', 'an optional tech label')
@enduml
```

## AmazonVpcVpnGatewayCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnGatewayCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway')

' renders the element
AmazonVpcVpnGatewayCard('AmazonVpcVpnGatewayCard', 'Amazon Vpc Vpn Gateway Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnGatewayCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway')

' renders the element
AmazonVpcVpnGatewayCard('AmazonVpcVpnGatewayCard', 'Amazon Vpc Vpn Gateway Card', 'an optional description')
@enduml
```

## AmazonVpcVpnGatewayGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnGatewayGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway')

' renders the element
AmazonVpcVpnGatewayGroup('AmazonVpcVpnGatewayGroup', 'Amazon Vpc Vpn Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnGatewayGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway')

' renders the element
AmazonVpcVpnGatewayGroup('AmazonVpcVpnGatewayGroup', 'Amazon Vpc Vpn Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway.md <==
# AmazonVpcVpnGateway


```text
aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway
```

```text
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway')
```



| Illustration | AmazonVpcVpnGateway | AmazonVpcVpnGatewayCard | AmazonVpcVpnGatewayGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway.png) | ![illustration for AmazonVpcVpnGateway](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway.Local.png) | ![illustration for AmazonVpcVpnGatewayCard](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGatewayCard.Local.png) | ![illustration for AmazonVpcVpnGatewayGroup](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGatewayGroup.Local.png) |




## AmazonVpcVpnGateway

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnGateway
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway')

' renders the element
AmazonVpcVpnGateway('AmazonVpcVpnGateway', 'Amazon Vpc Vpn Gateway', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnGateway
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway')

' renders the element
AmazonVpcVpnGateway('AmazonVpcVpnGateway', 'Amazon Vpc Vpn Gateway', 'an optional tech label')
@enduml
```

## AmazonVpcVpnGatewayCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnGatewayCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway')

' renders the element
AmazonVpcVpnGatewayCard('AmazonVpcVpnGatewayCard', 'Amazon Vpc Vpn Gateway Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnGatewayCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway')

' renders the element
AmazonVpcVpnGatewayCard('AmazonVpcVpnGatewayCard', 'Amazon Vpc Vpn Gateway Card', 'an optional description')
@enduml
```

## AmazonVpcVpnGatewayGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnGatewayGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway')

' renders the element
AmazonVpcVpnGatewayGroup('AmazonVpcVpnGatewayGroup', 'Amazon Vpc Vpn Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnGatewayGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnGateway')

' renders the element
AmazonVpcVpnGatewayGroup('AmazonVpcVpnGatewayGroup', 'Amazon Vpc Vpn Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
